<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>MainWindow</name>
    <message>
        <source>Basic Downloader</source>
        <translation>Téléchargeur basique</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Get List</source>
        <translation>Obtenir la liste</translation>
    </message>
    <message>
        <source>Enter URL:</source>
        <translation>Entrer l&apos;URL :</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Télécharger</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Options</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Code du format</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Extension</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Résolution</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Note</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Nom du moteur :</translation>
    </message>
    <message>
        <source>Paste Clipboard Content</source>
        <translation>Coller le contenu du presse papier</translation>
    </message>
    <message>
        <source>Recently Used</source>
        <translation>Récemment utilisés</translation>
    </message>
    <message>
        <source>Set Download Options</source>
        <translation>Définir les options de téléchargements</translation>
    </message>
    <message>
        <source>Batch Downloader</source>
        <translation>Téléchargeur par lots</translation>
    </message>
    <message>
        <source>Thumbnail</source>
        <translation>Miniatures</translation>
    </message>
    <message>
        <source>Url To Download</source>
        <translation>URL à télécharger</translation>
    </message>
    <message>
        <source>Paste Clipboard Url</source>
        <translation>Coller l&apos;URL depuis le presse-papier</translation>
    </message>
    <message>
        <source>Monitor Clipboard For Url</source>
        <translation>Inspecter le presse papier pour une URL</translation>
    </message>
    <message>
        <source>Add Url To List</source>
        <translation>Ajouter l&apos;URL à la liste</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Définir</translation>
    </message>
    <message>
        <source>Playlist Downloader</source>
        <translation>Téléchargeur de playlist</translation>
    </message>
    <message>
        <source>Download Options:</source>
        <translation>Options de téléchargements :</translation>
    </message>
    <message>
        <source>Time Interval Start Time(HH:MM:SS):</source>
        <translation>Temps de début de l&apos;intervalle de temps (HH:MM:SS)&#xa0;:</translation>
    </message>
    <message>
        <source>Time Interval End Time(HH:MM:SS):</source>
        <translation>Temps de fin de l&apos;intervalle de temps (HH:MM:SS)&#xa0;:</translation>
    </message>
    <message>
        <source>Chapters(Comma Separated):</source>
        <translation>Chapitres (séparés par des virgules) :</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Divisé par chapitres</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Masquer</translation>
    </message>
    <message>
        <source>Enter Playlist URL:</source>
        <translation>Entrer l&apos;URL de la playlist :</translation>
    </message>
    <message>
        <source>Clear Internal Archive File</source>
        <translation>Effacer le fichier d&apos;archive interne</translation>
    </message>
    <message>
        <source>Use Internal Archive File</source>
        <translation>Utiliser le fichier d&apos;archive interne</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliothèque</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Haut</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Rafraîchir</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Ouvrir le répertoire</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Accueil</translation>
    </message>
    <message>
        <source>Configure</source>
        <translation>Configurer</translation>
    </message>
    <message>
        <source>General Options</source>
        <translation>Options générales</translation>
    </message>
    <message>
        <source>Show Tray Icon</source>
        <translation>Montrer l&apos;icône de barre d&apos;état</translation>
    </message>
    <message>
        <source>Auto Save List Of Not Downloaded Media</source>
        <translation>Auto sauvegarde de la liste des médias non encore téléchargés</translation>
    </message>
    <message>
        <source>Auto Hide Downloads When Completed</source>
        <translation>Masquer automatiquement les téléchargements une fois terminés</translation>
    </message>
    <message>
        <source>Reset Option To Its Default</source>
        <translation>Reset des options par défaut</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Définir par défaut</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Options de préselection</translation>
    </message>
    <message>
        <source>Download Path</source>
        <translation>Chemin du téléchargement</translation>
    </message>
    <message>
        <source>Select Language</source>
        <translation>Sélectionner la langue</translation>
    </message>
    <message>
        <source>Use Manually Specified Proxy Configuration</source>
        <translation>Utiliser une configuration de proxy spécifiée manuellement</translation>
    </message>
    <message>
        <source>Get Proxy Configuration From The Environment</source>
        <translation>Récupérer la configuration du proxy à partir de l&apos;environnement</translation>
    </message>
    <message>
        <source>No Proxy</source>
        <translation>Pas de proxy</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Engine&apos;s Default Options</source>
        <translation>Options par défaut du moteur</translation>
    </message>
    <message>
        <source>File Size</source>
        <translation>Taille du fichier</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Obtenir la liste des options :</translation>
    </message>
    <message>
        <source>Subscriptions</source>
        <translation>Souscriptions</translation>
    </message>
    <message>
        <source>Ui Name</source>
        <translation>Nom Ui</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>Fait</translation>
    </message>
    <message>
        <source>Enable Library Tab</source>
        <translation>Activer l&apos;onglet Bibliothèque</translation>
    </message>
    <message>
        <source>Maximum Concurrent Downloads</source>
        <translation>Nombre maximal de téléchargements simultanés</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation>Encodage du texte</translation>
    </message>
    <message>
        <source>Show Version Info And Autodownload Updates</source>
        <translation>Afficher les informations de version et activer le téléchargement automatique des mises à jour</translation>
    </message>
    <message>
        <source>Show Version Info And Latest Version Info</source>
        <translation>Afficher les informations sur la version et les informations sur la dernière version</translation>
    </message>
    <message>
        <source>Show Version Info Only</source>
        <translation>Afficher uniquement les informations sur la version</translation>
    </message>
    <message>
        <source>Do Nothing</source>
        <translation>Ne rien faire</translation>
    </message>
    <message>
        <source>Actions At Startup</source>
        <translation>Actions au démarrage</translation>
    </message>
    <message>
        <source>Website</source>
        <translation>Site web</translation>
    </message>
    <message>
        <source>Engine&apos;s Name</source>
        <translation>Nom du moteur</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Défaut</translation>
    </message>
    <message>
        <source>Options To Add</source>
        <translation>Options à ajouter</translation>
    </message>
    <message>
        <source>Url Manager</source>
        <translation>Gestionnaire URL</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Options de téléchargement</translation>
    </message>
    <message>
        <source>Set What Url Should Be Managed By What Engine</source>
        <translation>Définir quelle URL sera traitée par quel moteur</translation>
    </message>
    <message>
        <source>Url Filter</source>
        <translation>Filtre URL</translation>
    </message>
    <message>
        <source>Proxy Settings</source>
        <translation>Paramètres du proxy</translation>
    </message>
    <message>
        <source>Use System Proxy Configuration</source>
        <translation>Utiliser la configuration du proxy système</translation>
    </message>
    <message>
        <source>Manually Specified Proxy Configuration
Example 1: 192.168.93.89:8080
Exampe 2: ${gateway}:8080</source>
        <translation>Configuration de proxy spécifiée manuellement
Exemple 1&#xa0;: 192.168.93.89:8080
Exemple 2&#xa0;: ${gateway}:8080</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>Play Downloaded Media</source>
        <translation>Lire les médias téléchargés</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <source>Enter Playlist Url. To Add Multiple Playlists, Separate Them With A Space Or New Line</source>
        <translation>Saisissez l&apos;URL de la playlist. Pour ajouter plusieurs playlists, séparez-les par un espace ou un saut de ligne</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>Renommez le fichier avec le texte ci-dessous</translation>
    </message>
    <message>
        <source>A Button To Open A Folder To Be Used As A Download Folder</source>
        <translation>Un bouton pour ouvrir un dossier à utiliser comme dossier de téléchargement</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Theme Config Files Are Stored</source>
        <translation>Un bouton pour ouvrir le dossier contenant les fichiers de configuration du thème</translation>
    </message>
    <message>
        <source>A Button To Open A Folder Where Extension&apos;s Binaries Are Stored</source>
        <translation>Un bouton pour ouvrir le dossier contenant les fichiers binaires de l&apos;extension</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Reset These Options To Their Defaults?</source>
        <translation>Êtes-vous sûr de vouloir rétablir les valeurs par défaut de ces options&#xa0;?</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation>Nom du navigateur Web auprès duquel récupérer les cookies</translation>
    </message>
    <message>
        <source>Theme(Need A Restart)</source>
        <translation>Thème (Redémarrage requis)</translation>
    </message>
    <message>
        <source>Switch Between Setting Browser Name And Path To Cookie File</source>
        <translation>Basculer entre la configuration du nom du navigateur et du chemin d&apos;accès au fichier de cookies</translation>
    </message>
    <message>
        <source>Show MetaData In Batch Downloader</source>
        <translation>Afficher les métadonnées dans le téléchargeur par lots</translation>
    </message>
    <message>
        <source>Auto Download Added Entries In Batch Downloader</source>
        <translation>Télécharger automatiquement les entrées ajoutées au téléchargeur par lots</translation>
    </message>
    <message>
        <source>Notify When Download Completes</source>
        <translation>Prévenir lorsque le téléchargement est terminé</translation>
    </message>
    <message>
        <source>Notify When All Downloads Complete</source>
        <translation>Prévenir lorsque tous les téléchargements sont terminés</translation>
    </message>
    <message>
        <source>Engine&apos;s Options</source>
        <translation>Options du moteur</translation>
    </message>
    <message>
        <source>Extensions</source>
        <translation>Extensions</translation>
    </message>
    <message>
        <source>Remove An Extension</source>
        <translation>Supprimer une extension</translation>
    </message>
    <message>
        <source>Update An Extension</source>
        <translation>Mettre à jour une extension</translation>
    </message>
    <message>
        <source>Add An Extension</source>
        <translation>Ajouter une extension</translation>
    </message>
    <message>
        <source>Open Binary Folder</source>
        <translation>Ouvrir le dossier binaire</translation>
    </message>
    <message>
        <source>Open Extension Folder</source>
        <translation>Ouvrir le dossier de l&apos;extension</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>%1 Preset Options</source>
        <translation>%1 options prédéfinies</translation>
    </message>
    <message>
        <source>Filename with &quot;.txt&quot; Extension Will Save Urls Only</source>
        <translation>Les noms de fichiers avec l&apos;extension « .txt » seront sauvegardés comme des URL seulement</translation>
    </message>
    <message>
        <source>Hide Row</source>
        <translation>Masquer la ligne</translation>
    </message>
    <message>
        <source>Unhide All Hidden Rows</source>
        <translation>Afficher toutes les lignes masquées</translation>
    </message>
    <message>
        <source>Failed To Start Executable %1</source>
        <translation>Échec du lancement du fichier exécutable %1</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Copier l&apos;URL</translation>
    </message>
    <message>
        <source>Open Url With %1</source>
        <translation>Ouvrir l&apos;URL avec %1</translation>
    </message>
    <message>
        <source>Copy Url %1</source>
        <translation>Copier l&apos;URL %1</translation>
    </message>
    <message>
        <source>Save List To File</source>
        <translation>Enregistrer la liste dans un fichier</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Date</translation>
    </message>
    <message>
        <source>Replies to</source>
        <translation>Réponse à</translation>
    </message>
    <message>
        <source>Save Subtitle To File</source>
        <translation>Sauvegarder les sous titres dans un fichier</translation>
    </message>
    <message>
        <source>Engine Name:</source>
        <translation>Nom du moteur :</translation>
    </message>
    <message>
        <source>Get List From File</source>
        <translation>Obtenir la liste depuis un fichier</translation>
    </message>
    <message>
        <source>Preset Options</source>
        <translation>Options de préselection</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Open Download Folder</source>
        <translation>Ouvrir le répertoire de téléchargement</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Project Page</source>
        <translation>Page du projet</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <source>License</source>
        <translation>Licence</translation>
    </message>
    <message>
        <source>Email</source>
        <translation>Adresse électronique</translation>
    </message>
    <message>
        <source>Qt Version</source>
        <translation>Version de Qt</translation>
    </message>
    <message>
        <source>This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.</source>
        <translation>Ce programme est un logiciel libre ; vous pouvez le redistribuer et/ou le modifier selon les termes de la licence publique générale GNU telle que publiée par la Free Software Foundation ; soit la version 2 de la licence, soit (à votre choix) toute version ultérieure.</translation>
    </message>
    <message>
        <source>This program is distributed in the hope that it will be useful,but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.</source>
        <translation>Ce programme est distribué dans l&apos;espoir qu&apos;il sera utile, mais SANS AUCUNE GARANTIE ; sans même la garantie implicite de QUALITÉ MARCHANDE ou d&apos;ADÉQUATION À UN USAGE PARTICULIER. Voir la licence publique générale GNU pour plus de détails.</translation>
    </message>
    <message>
        <source>Polish (Poland)</source>
        <translation>Polonais (Pologne)</translation>
    </message>
    <message>
        <source>English (US)</source>
        <translation>Anglais (États-Unis)</translation>
    </message>
    <message>
        <source>Spanish (Spain)</source>
        <translation>Espagnol (Espagne)</translation>
    </message>
    <message>
        <source>Chinese (China)</source>
        <translation>Chinois (Chine)</translation>
    </message>
    <message>
        <source>Turkish (Turkey)</source>
        <translation>Turc (Turquie)</translation>
    </message>
    <message>
        <source>Russian (Russia)</source>
        <translation>Russe (Russie)</translation>
    </message>
    <message>
        <source>Japanese (Japan)</source>
        <translation>Japonais (Japon)</translation>
    </message>
    <message>
        <source>French (France)</source>
        <translation>Français (France)</translation>
    </message>
    <message>
        <source>Italian (Italy)</source>
        <translation>Italien (Italie)</translation>
    </message>
    <message>
        <source>Swedish (Sweden)</source>
        <translation>Suédois (Suède)</translation>
    </message>
    <message>
        <source>German (Germany)</source>
        <translation>Allemand (Allemagne)</translation>
    </message>
    <message>
        <source>Portuguese (Brazil)</source>
        <translation>Portugais (Brésil)</translation>
    </message>
    <message>
        <source>Dutch (Netherlands)</source>
        <translation>Néerlandais (Pays-Bas)</translation>
    </message>
    <message>
        <source>Error, executable to backend &quot;%1&quot; could not be found</source>
        <translation>Erreur, l&apos;exécutable vers le programme « %1 » n&apos;a pas été trouvé</translation>
    </message>
    <message>
        <source>Engine &quot;%1&quot; requires atleast version &quot;%2&quot; of Media Downloader</source>
        <translation>Le moteur « %1 » nécessite au moins la version « %2 » de Media Downloader</translation>
    </message>
    <message>
        <source>To Disable These Checks, Do The Following:-</source>
        <translation>Pour désactiver ces tests, essayez ceci : -</translation>
    </message>
    <message>
        <source>1. Go To &quot;Configure&quot; Tab.</source>
        <translation>1. Aller à l&apos;onglet « Configurer ».</translation>
    </message>
    <message>
        <source>2. Go To &quot;General Options&quot; Sub Tab.</source>
        <translation>2. Aller au sous-onglet « Options générales ».</translation>
    </message>
    <message>
        <source>3. Click &quot;Actions At StartUp&quot; Menu.</source>
        <translation>3. Cliquer sur le menu « Actions au démarrage ».</translation>
    </message>
    <message>
        <source>4. Select &quot;Do Nothing&quot;.</source>
        <translation>4. Sélectionner « Ne rien faire ».</translation>
    </message>
    <message>
        <source>Running In Portable Mode</source>
        <translation>Exécution en mode portable</translation>
    </message>
    <message>
        <source>Running In Installation Mode</source>
        <translation>Exécution en mode installation</translation>
    </message>
    <message>
        <source>Download Path: %1</source>
        <translation>Chemin de téléchargement : %1</translation>
    </message>
    <message>
        <source>App Data Path: %1</source>
        <translation>Chemin des données de l&apos;application&#xa0;: %1</translation>
    </message>
    <message>
        <source>Setting Proxy Server Address Of %1</source>
        <translation>Configuration de l&apos;adresse du serveur proxy %1</translation>
    </message>
    <message>
        <source>Unsetting Proxy Server Address</source>
        <translation>Suppression de l&apos;adresse du serveur proxy</translation>
    </message>
    <message>
        <source>Error, failed to parse config file &quot;%1&quot;</source>
        <translation>Erreur, échec à séparer le fichier de config  « %1 »</translation>
    </message>
    <message>
        <source>Failed To Load A Plugin</source>
        <translation>Echec à charger le plugin</translation>
    </message>
    <message>
        <source>Failed to find executable &quot;%1&quot;</source>
        <translation>Impossible de trouver le fichier exécutable « %1 »</translation>
    </message>
    <message>
        <source>Failed to find python3 executable for backend &quot;%1&quot;</source>
        <translation>Impossible de trouver l&apos;exécutable python3 pour le backend « %1 »</translation>
    </message>
    <message>
        <source>Network Error Occured</source>
        <translation>Une erreur réseau s&apos;est produite</translation>
    </message>
    <message>
        <source>Url Is Not Supported</source>
        <translation>L&apos;URL n&apos;est pas prise en charge</translation>
    </message>
    <message>
        <source>Download cancelled</source>
        <translation>Téléchargement annulé</translation>
    </message>
    <message>
        <source>ErrorCode</source>
        <translation>Code d&apos;erreur</translation>
    </message>
    <message>
        <source>Download Failed, Engine failed to start</source>
        <translation>Échec du téléchargement, impossible de démarrer le moteur</translation>
    </message>
    <message>
        <source>Download Failed, Engine crashed</source>
        <translation>Échec du téléchargement, le moteur a planté</translation>
    </message>
    <message>
        <source>Format Code</source>
        <translation>Code du format</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>Extension</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Résolution</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Note</translation>
    </message>
    <message>
        <source>Failed to open file for writing</source>
        <translation>Echec à ouvrir le fichier en écriture</translation>
    </message>
    <message>
        <source>Failed to open file for reading</source>
        <translation>Echec à ouvrir le fichier en lecture</translation>
    </message>
    <message>
        <source>Elapsed Time:</source>
        <translation>Temps écoulé :</translation>
    </message>
    <message>
        <source>Failed to find version information, make sure &quot;%1&quot; is installed and works properly</source>
        <translation>Les informations de version n&apos;ont pas été trouvées, vérifiez que « %1 » est bien installé et fonctionne correctement</translation>
    </message>
    <message>
        <source>Found version</source>
        <translation>Version trouvée</translation>
    </message>
    <message>
        <source>Failed To Open Path For Writing: %1</source>
        <translation>Impossible d&apos;ouvrir le chemin d&apos;écriture&#xa0;: %1</translation>
    </message>
    <message>
        <source>Failed To Extract</source>
        <translation>Échec de l&apos;extraction</translation>
    </message>
    <message>
        <source>Network Failed To Respond Within %1 seconds</source>
        <translation>Le réseau a échoué à répondre en moins de %1 seconds</translation>
    </message>
    <message>
        <source>Failed to download, Following path can not be created: </source>
        <translation>Échec du téléchargement, le chemin suivant ne peut pas être créé : </translation>
    </message>
    <message>
        <source>Start Downloading</source>
        <translation>Débuter le téléchargement</translation>
    </message>
    <message>
        <source>Trouble Ahead, Failed To Delete Folder: %1</source>
        <translation>Problème en vue, échec de la suppression du dossier&#xa0;: %1</translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar.exe&quot; Executable</source>
        <translation>Impossible de trouver le fichier exécutable « bsdtar.exe »</translation>
    </message>
    <message>
        <source>Download Failed</source>
        <translation>Echec du téléchargement</translation>
    </message>
    <message>
        <source>Failed to parse json file from github</source>
        <translation>Impossible d&apos;analyser le fichier JSON provenant de GitHub</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Téléchargement</translation>
    </message>
    <message>
        <source>Destination</source>
        <translation>Destination</translation>
    </message>
    <message>
        <source>Update Complete, Restart To Use New Version</source>
        <translation>Mise à jour terminée,veuillez redémarrer pour utiliser la nouvelle version</translation>
    </message>
    <message>
        <source>Windows&apos; Secure Channel</source>
        <translation>Canal sécurisé de Windows</translation>
    </message>
    <message>
        <source>File Not Found</source>
        <translation>Fichier introuvable</translation>
    </message>
    <message>
        <source>Download complete</source>
        <translation>Téléchargement complet</translation>
    </message>
    <message>
        <source>Extracting archive: </source>
        <translation>Extraction de l&apos;archive : </translation>
    </message>
    <message>
        <source>Processing</source>
        <translation>Traitement</translation>
    </message>
    <message>
        <source>Download completed</source>
        <translation>Téléchargement complet</translation>
    </message>
    <message>
        <source>Resetting download folder to default</source>
        <translation>Reset du dossier de téléchargement par défaut</translation>
    </message>
    <message>
        <source>Post Processing</source>
        <translation>Post-traitement</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Télécharger</translation>
    </message>
    <message>
        <source>Force Download</source>
        <translation>Téléchargement forcé</translation>
    </message>
    <message>
        <source>Show Log Window</source>
        <translation>Montrer la fenêtre des journaux</translation>
    </message>
    <message>
        <source>Upload Date:</source>
        <translation>Date de téléversement :</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Durée :</translation>
    </message>
    <message>
        <source>Subtitle Name</source>
        <translation>Sous-titres</translation>
    </message>
    <message>
        <source>Download Options</source>
        <translation>Options de téléchargement</translation>
    </message>
    <message>
        <source>Extra Downloading Options</source>
        <translation>Options extra de téléchargement</translation>
    </message>
    <message>
        <source>Download Time Interval</source>
        <translation>Intervalle de temps de téléchargement</translation>
    </message>
    <message>
        <source>Download Chapters</source>
        <translation>Télécharger les chapitres</translation>
    </message>
    <message>
        <source>Split By Chapters</source>
        <translation>Diviser par chapitres</translation>
    </message>
    <message>
        <source>Media Already In Archive</source>
        <translation>Media déjà dans l&apos;archive</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Foncé</translation>
    </message>
    <message>
        <source>Method</source>
        <translation>Méthode</translation>
    </message>
    <message>
        <source>Time Left</source>
        <translation>Temps restant</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Téléchargé</translation>
    </message>
    <message>
        <source>%1 Already Downloaded</source>
        <translation>%1 déjà téléchargé</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Ceci peut prendre un certain temps</translation>
    </message>
    <message>
        <source>Speed:</source>
        <translation>Vitesse :</translation>
    </message>
    <message>
        <source>There Is An Update For %1</source>
        <translation>Il y a une mise à jour pour %1</translation>
    </message>
    <message>
        <source>Newest Version Is %1, Updating</source>
        <translation>La version la plus récente est %1, mise à jour en cours</translation>
    </message>
    <message>
        <source>Checking installed version of %1</source>
        <translation>Vérification de la version installée de %1</translation>
    </message>
    <message>
        <source>Found version: %1</source>
        <translation>Version trouvée : %1</translation>
    </message>
    <message>
        <source>Newest Version Is: %1</source>
        <translation>La version la plus récente est&#xa0;: %1</translation>
    </message>
    <message>
        <source>Please Update &quot;%1&quot; To Atleast Version &quot;%2&quot;</source>
        <translation>Veuillez mettre à jour « %1 » au moins vers la version « %2 »</translation>
    </message>
    <message>
        <source>Requested Format Is Not Available</source>
        <translation>Le format demandé n&apos;est pas disponible</translation>
    </message>
    <message>
        <source>Invalid Url Entered</source>
        <translation>URL invalide saisie</translation>
    </message>
    <message>
        <source>Best Available Audio Only</source>
        <translation>Meilleur audio disponible uniquement</translation>
    </message>
    <message>
        <source>Best Available Audio Only(MP3)</source>
        <translation>Meilleur audio disponible uniquement (MP3)</translation>
    </message>
    <message>
        <source>Best Available Audio Video</source>
        <translation>Meilleur audio vidéo disponible</translation>
    </message>
    <message>
        <source>Best Audio With Video Resolution Of %1</source>
        <translation>Meilleure qualité audio avec une résolution vidéo de %1</translation>
    </message>
    <message>
        <source>Warning: Skipping Clipboard Content</source>
        <translation>Attention : contenu du presse-papiers ignoré</translation>
    </message>
    <message>
        <source>Show Folders First</source>
        <translation>Afficher les dossiers en premier</translation>
    </message>
    <message>
        <source>Arrange In Ascending Order</source>
        <translation>Classer par ordre croissant</translation>
    </message>
    <message>
        <source>Arrange By Date</source>
        <translation>Classer par date</translation>
    </message>
    <message>
        <source>Arrange By Name</source>
        <translation>Classer par nom</translation>
    </message>
    <message>
        <source>Arrange In Descending Order</source>
        <translation>Classer par ordre décroissant</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtre</translation>
    </message>
    <message>
        <source>No Filter</source>
        <translation>Aucun filtre</translation>
    </message>
    <message>
        <source>Other Websites</source>
        <translation>Autres sites Web</translation>
    </message>
    <message>
        <source>Extract Audio</source>
        <translation>Extraire l&apos;audio</translation>
    </message>
    <message>
        <source>Extract Audio As MP3</source>
        <translation>Extraire l&apos;audio au format MP3</translation>
    </message>
    <message>
        <source>Arabic</source>
        <translation>Arabe</translation>
    </message>
    <message>
        <source>Best Available Audio Only+Thumbnail</source>
        <translation>Meilleur audio disponible uniquement + vignette</translation>
    </message>
    <message>
        <source>Youtube</source>
        <translation>YouTube</translation>
    </message>
    <message>
        <source>Autoupdate Disabled For %1</source>
        <translation>Mise à jour automatique désactivée pour %1</translation>
    </message>
    <message>
        <source>Newest Version Is %1, AutoUpdate Disabled</source>
        <translation>La version la plus récente est %1, mise à jour automatique désactivée</translation>
    </message>
    <message>
        <source>Author: %1</source>
        <translation>Auteur&#xa0;: %1</translation>
    </message>
    <message>
        <source>Like Count: %1</source>
        <translation>Nombre de « J&apos;aime » : %1 </translation>
    </message>
    <message>
        <source>Korean (Korea)</source>
        <translation>Coréen (Corée)</translation>
    </message>
    <message>
        <source>Sign In To Confirm You Are Not A Bot</source>
        <translation>Connectez-vous pour confirmer que vous n&apos;êtes pas un robot</translation>
    </message>
    <message>
        <source>Show/Hide Controls</source>
        <translation>Afficher/Masquer les commandes</translation>
    </message>
    <message>
        <source>Merging Audio and Video Together</source>
        <translation>Fusionner l&apos;audio et la vidéo</translation>
    </message>
    <message>
        <source>Remuxing video</source>
        <translation>Remuxage de la vidéo</translation>
    </message>
    <message>
        <source>Greek (Greece)</source>
        <translation>Grec (Grèce)</translation>
    </message>
    <message>
        <source>Platform Default</source>
        <translation>Valeur par défaut de la plateforme</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Clair</translation>
    </message>
    <message>
        <source>Failed To Rename</source>
        <translation>Échec du changement de nom</translation>
    </message>
    <message>
        <source>Completed: %1, Running: %2, Not Started: %3, Succeeded: %4, Failed: %5, Cancelled: %6</source>
        <translation>Terminé(s) : %1, En cours : %2, Non démarré(s) : %3, Réussi(s) : %4, Échec(s) : %5, Annulé(s) : %6</translation>
    </message>
    <message>
        <source>Stopping Because Media Is Already In Archive File</source>
        <translation>Arrêt de l&apos;opération car le fichier multimédia est déjà archivé</translation>
    </message>
    <message>
        <source>Bulgarien (Bulgaria)</source>
        <translation>Bulgare (Bulgarie)</translation>
    </message>
    <message>
        <source>Open Urls With %2</source>
        <translation>Ouvrir les URL avec %2</translation>
    </message>
    <message>
        <source>Default Player</source>
        <translation>Lecteur par défaut</translation>
    </message>
    <message>
        <source>Warning, Nothing Was Downloaded</source>
        <translation>Avertissement&#xa0;: aucun téléchargement n&apos;a été effectué</translation>
    </message>
    <message>
        <source>Download Cancelled, Playlist Urls Are Not Allowed In This Tab</source>
        <translation>Téléchargement annulé. Les URL de playlists ne sont pas autorisées dans cet onglet</translation>
    </message>
    <message>
        <source>Download Cancelled Because A Condition Was Not Met</source>
        <translation>Téléchargement annulé car une condition n&apos;a pas été remplie</translation>
    </message>
    <message>
        <source>Download Failed, Unknown Reason</source>
        <translation>Échec du téléchargement, raison inconnue</translation>
    </message>
    <message>
        <source>Download Failed, Network Issue</source>
        <translation>Échec du téléchargement, problème de réseau</translation>
    </message>
    <message>
        <source>Ukrainian (Ukraine)</source>
        <translation>Ukrainien (Ukraine)</translation>
    </message>
    <message>
        <source>Renaming &quot;%1&quot; to &quot;%2&quot;</source>
        <translation>Renommage de « %1 » en « %2 »</translation>
    </message>
    <message>
        <source>Renaming Failed: %3</source>
        <translation>Échec du renommage&#xa0;: %3</translation>
    </message>
    <message>
        <source>Skipping Checking Download Hash</source>
        <translation>Vérification du hachage de téléchargement ignorée</translation>
    </message>
    <message>
        <source>Ignoring Download Because Hashes Do Not Match</source>
        <translation>Téléchargement ignoré car les hachages ne correspondent pas</translation>
    </message>
    <message>
        <source>Expected &quot;%1&quot; but obtained &quot;%2&quot;</source>
        <translation>Attendu «&#xa0;%1&#xa0;», mais obtenu «&#xa0;%2&#xa0;»</translation>
    </message>
    <message>
        <source>Failed To Remove</source>
        <translation>Échec de la suppression</translation>
    </message>
    <message>
        <source>Renaming file to: %1</source>
        <translation>Renommage du fichier en&#xa0;: %1</translation>
    </message>
    <message>
        <source>Skipping Checking Version Info For Engine &quot;%1&quot;</source>
        <translation>Vérification des informations de version ignorée pour le moteur «&#xa0;%1&#xa0;»</translation>
    </message>
    <message>
        <source>Failed To Find &quot;bsdtar&quot; or &quot;unzip&quot; Executable</source>
        <translation>Impossible de trouver l&apos;exécutable « bsdtar » ou « unzip »</translation>
    </message>
</context>
<context>
    <name>basicdownloader</name>
    <message>
        <source>Hide List</source>
        <translation>Masquer la liste</translation>
    </message>
</context>
<context>
    <name>batchdownloader</name>
    <message>
        <source>Set Batch File</source>
        <translation>Définir le fichier batch</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Downloading comments</source>
        <translation>Téléchargement des commentaires</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Télécharger</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Copier l&apos;URL</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
    <message>
        <source>Show Subtitles</source>
        <translation>Montrer les sous-titres</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Montrer les annotations</translation>
    </message>
    <message>
        <source>Show Media Options</source>
        <translation>Montrer les options de média</translation>
    </message>
    <message>
        <source>Download Media Part</source>
        <translation>Téléchargement de la partie du média</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Définir</translation>
    </message>
    <message>
        <source>Downloading subtitles</source>
        <translation>Téléchargement des sous-titres</translation>
    </message>
    <message>
        <source>Sort By Date Ascending</source>
        <translation>Trier par date croissante</translation>
    </message>
    <message>
        <source>Sort By Date Descending</source>
        <translation>Trier par date décroissante</translation>
    </message>
    <message>
        <source>Sort By Likes</source>
        <translation>Trier par «&#xa0;J&apos;aime&#xa0;»</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
</context>
<context>
    <name>configure</name>
    <message>
        <source>Set As Default</source>
        <translation>Définir par défaut</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>Copier</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
    <message>
        <source>Select An Engine File</source>
        <translation>Sélectionner un fichier moteur</translation>
    </message>
    <message>
        <source>Set Download Folder</source>
        <translation>Définir le répertoire de téléchargement</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Modifier</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Set Defaults</source>
        <translation>Définir les valeurs par défaut</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Select A Cookie File</source>
        <translation>Sélectionnez un fichier cookie</translation>
    </message>
    <message>
        <source>Name Of Web Browser To Get Cookies From</source>
        <translation>Nom du navigateur Web auprès duquel récupérer les cookies</translation>
    </message>
    <message>
        <source>Set Path To Cookie File</source>
        <translation>Définir le chemin d&apos;accès au fichier de cookies</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <source>Delete</source>
        <translation>Effacer</translation>
    </message>
    <message>
        <source>Delete All</source>
        <translation>Effacer TOUT</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Renommer</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below File?</source>
        <translation>Êtes-vous sûr de vouloir supprimer le fichier ci-dessous&#xa0;?</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Below Folder?</source>
        <translation>Êtes-vous sûr de vouloir supprimer le dossier ci-dessous&#xa0;?</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Oui</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Non</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete All Files And Folders?</source>
        <translation>Êtes-vous sûr de vouloir supprimer tous les fichiers et dossiers&#xa0;?</translation>
    </message>
    <message>
        <source>Rename File To Below Text</source>
        <translation>Renommer le fichier avec le texte ci-dessous</translation>
    </message>
    <message>
        <source>Rename Folder To Below Text</source>
        <translation>Renommer le dossier avec le texte ci-dessous</translation>
    </message>
    <message>
        <source>Are You Sure You Want To Delete Selected Items?</source>
        <translation>Êtes-vous sûr de vouloir supprimer les éléments sélectionnés&#xa0;?</translation>
    </message>
</context>
<context>
    <name>logWindow</name>
    <message>
        <source>Log Window</source>
        <translation>Fenêtre de journal</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
    <message>
        <source>Show All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>playlistdownloader</name>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Retirer</translation>
    </message>
    <message>
        <source>Hide Controls</source>
        <translation>Masquer les commandes</translation>
    </message>
    <message>
        <source>Get List Options:</source>
        <translation>Obtenir la liste des options :</translation>
    </message>
    <message>
        <source>Copy Url</source>
        <translation>Copier l&apos;URL</translation>
    </message>
    <message>
        <source>Show Comments</source>
        <translation>Montrer les annotations</translation>
    </message>
    <message>
        <source>Show All Updated</source>
        <translation>Montrer toutes les nouveautés</translation>
    </message>
    <message>
        <source>Download All Updated</source>
        <translation>Télécharger toutes les nouveautés</translation>
    </message>
    <message>
        <source>Manage Subscriptions</source>
        <translation>Gérer les souscriptions</translation>
    </message>
    <message>
        <source>Number of Pages Downloaded</source>
        <translation>Nombre de pages téléchargées</translation>
    </message>
    <message>
        <source>Downloading video info</source>
        <translation>Téléchargement des infos vidéos</translation>
    </message>
    <message>
        <source>Show Controls</source>
        <translation>Afficher les commandes</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Masquer</translation>
    </message>
    <message>
        <source>This May Take A Very Long Time</source>
        <translation>Ceci peut prendre un certain temps</translation>
    </message>
</context>
</TS>
